import { Rule, RuleDefinition } from '../Rule';
import { LeafNode } from './Leaf';
/**
 * An abstract node class that is extended by the different types of nodes.
 */
export declare abstract class Node {
    protected readonly parent: Node | false;
    protected readonly condition: Rule;
    /**
     * `parent` is `false` when the node being considered is the root node.
     */
    constructor({ condition }: CommonNodeDefinition, parent: Node | false);
    abstract evaluate(data: any): any;
    abstract toJSON(): any;
    getParent(): false | Node;
    isLeafNode(): this is LeafNode;
}
/**
 * All nodes have a `condition` to be evaluated.
 */
export interface CommonNodeDefinition {
    condition: RuleDefinition;
}
